/* SPDX-License-Identifier: Zlib */

#ifndef GIRARA_H
#define GIRARA_H

#include "types.h"
#include "session.h"
#include "utils.h"
#include "datastructures.h"
#include "settings.h"
#include "completion.h"
#include "config.h"
#include "statusbar.h"
#include "shortcuts.h"
#include "commands.h"
#include "callbacks.h"
#include "input-history.h"

#endif
